@@ -30,6 +30,7 @@ from holmes.handlers.bus import EventBusHandler
 from holmes.event_bus import EventBus, NoOpEventBus
 from holmes.utils import load_classes
 from holmes.models import Key
+from holmes.cache import Cache
 
 
 def main():
@@ -114,6 +115,8 @@ class HolmesApiServer(Server):
         self.application.http_client = AsyncHTTPClient(io_loop=io_loop)
         self.connect_pub_sub(io_loop)
 
+        self.application.cache = Cache(self.application)
+
     def _insert_keys(self, keys):
         for name in keys:
             key = Key.get_or_create(self.application.db, name)
